@@ -1,5 +1,5 @@
 
-#' @title Get Token
+#' @title Get authentication token
 #' @description getToken() returns a token needed to run getArthroCollections() and getPools(). Prints agencies associated with account credentials. The function prompts users for a VectorSurv account credentials.
 #' @keywords authentication
 #' @return User token
@@ -31,13 +31,13 @@ getToken = function(){
 
   response_content <- content(response, 'parsed')
   if(is.null(response_content$token)){
-    stop("Error, check returned response above")
+    stop(content(response, 'parsed'))
   }
     token <- response_content$token
     agencies = c()
    for (i in 1:length(response_content$agencies)){
 
-     agencies = rbind(agencies,paste("Id:",response_content$agencies[[i]]$id,"Name:",response_content$agencies[[i]]$name, sep=" "))
+     agencies = rbind(agencies,paste("Agency Id:",response_content$agencies[[i]]$id,"| Agency Name:",response_content$agencies[[i]]$name, sep=" "))
 
    }
 
